← Back to team overview

launchpad-reviewers team mailing list archive

[Merge] lp:~cjwatson/launchpad/typos into lp:launchpad

 

Colin Watson has proposed merging lp:~cjwatson/launchpad/typos into lp:launchpad.

Requested reviews:
  Launchpad code reviewers (launchpad-reviewers)

For more details, see:
https://code.launchpad.net/~cjwatson/launchpad/typos/+merge/87726

Fix a slew of typos that have been annoying me.  There should be no functional changes here.
-- 
https://code.launchpad.net/~cjwatson/launchpad/typos/+merge/87726
Your team Launchpad code reviewers is requested to review the proposed merge of lp:~cjwatson/launchpad/typos into lp:launchpad.
=== modified file 'database/replication/report.py'
--- database/replication/report.py	2011-12-30 06:47:54 +0000
+++ database/replication/report.py	2012-01-06 11:15:30 +0000
@@ -7,7 +7,7 @@
 
 This report spits out whatever we consider useful for checking up on and
 diagnosing replication. This report will grow over time, and maybe some
-bits of this will move to seperate monitoring systems or reports.
+bits of this will move to separate monitoring systems or reports.
 
 See the Slony-I documentation for more discussion on the data presented
 by this report.

=== modified file 'database/schema/archive/patch-2207-35-2.sql'
--- database/schema/archive/patch-2207-35-2.sql	2010-08-17 11:25:16 +0000
+++ database/schema/archive/patch-2207-35-2.sql	2012-01-06 11:15:30 +0000
@@ -1,7 +1,7 @@
 SET client_min_messages=ERROR;
 
 /* This table is populated and triggers added to keep it up to date
-in patch-2207-44-0.sql. The table creation is in a seperate DB
+in patch-2207-44-0.sql. The table creation is in a separate DB
 patch to we can install it on production before rollout and grant
 required permissions. */
 CREATE TABLE lp_Account (

=== modified file 'doc/email.txt'
--- doc/email.txt	2011-09-16 01:12:30 +0000
+++ doc/email.txt	2012-01-06 11:15:30 +0000
@@ -144,7 +144,7 @@
 defines a single `send` method. There are two standard `IMailDelivery`
 implementations:
 
-    1. `QueuedDelivery` -- email is delivered in a seperate thread. We use
+    1. `QueuedDelivery` -- email is delivered in a separate thread. We use
        this for production.
 
     2. `DirectDelivery` -- email is send synchronously during transaction

=== modified file 'lib/lp/answers/browser/questiontarget.py'
--- lib/lp/answers/browser/questiontarget.py	2012-01-01 02:58:52 +0000
+++ lib/lp/answers/browser/questiontarget.py	2012-01-06 11:15:30 +0000
@@ -279,7 +279,7 @@
         """See `LaunchpadFormView`."""
         LaunchpadFormView.setUpWidgets(self)
         # Make sure that the default filter is displayed
-        # correctly in the widgets when not overriden by the user
+        # correctly in the widgets when not overridden by the user
         for name, value in self.getDefaultFilter().items():
             widget = self.widgets.get(name)
             if widget and not widget.hasValidInput():

=== modified file 'lib/lp/app/doc/hierarchical-menu.txt'
--- lib/lp/app/doc/hierarchical-menu.txt	2011-12-30 07:50:11 +0000
+++ lib/lp/app/doc/hierarchical-menu.txt	2012-01-06 11:15:30 +0000
@@ -173,7 +173,7 @@
 The construction of breadcrumb objects is handled by an IBreadcrumb adapter,
 which adapts a context object and produces an IBreadcrumb object for that
 context.  The default adapter provides the url attribute, but the breadcrumb's
-text must be overriden in subclasses.
+text must be overridden in subclasses.
 
     >>> from zope.interface.verify import verifyObject
     >>> from lp.services.webapp.interfaces import IBreadcrumb

=== modified file 'lib/lp/app/doc/launchpadform.txt'
--- lib/lp/app/doc/launchpadform.txt	2012-01-05 19:57:47 +0000
+++ lib/lp/app/doc/launchpadform.txt	2012-01-06 11:15:30 +0000
@@ -20,7 +20,7 @@
    support submission.
 
  * if form wide validation is needed, the validate() method should be
-   overriden. Errors are reported using the addError() and
+   overridden. Errors are reported using the addError() and
    setFieldError() methods.
 
  * if a form contains multiple actions, the validate_widgets method

=== modified file 'lib/lp/app/javascript/autocomplete/assets/skins/sam/autocomplete-skin.css'
--- lib/lp/app/javascript/autocomplete/assets/skins/sam/autocomplete-skin.css	2011-06-29 14:56:15 +0000
+++ lib/lp/app/javascript/autocomplete/assets/skins/sam/autocomplete-skin.css	2012-01-06 11:15:30 +0000
@@ -213,7 +213,7 @@
 
 .yui3-skin-sam .yui3-splitbuttonnav .yui3-menu-label .yui3-menu-toggle {
 
-    padding: 0; /* Overide padding applied by the preceeding rule. */
+    padding: 0; /* Override padding applied by the preceding rule. */
     border-left: solid 1px #ccc;
     width: 15px;
     overflow: hidden;

=== modified file 'lib/lp/app/widgets/doc/zope3-widgets-use-form-ng.txt'
--- lib/lp/app/widgets/doc/zope3-widgets-use-form-ng.txt	2011-12-24 17:49:30 +0000
+++ lib/lp/app/widgets/doc/zope3-widgets-use-form-ng.txt	2012-01-06 11:15:30 +0000
@@ -53,7 +53,7 @@
       ...
     UnexpectedFormData: ...
 
-Since the SimpleInputWidget._getFormValue is overriden, it also works
+Since the SimpleInputWidget._getFormValue is overridden, it also works
 with the Launchpad widgets extending it:
 
     >>> from lp.app.widgets.textwidgets import StrippedTextWidget

=== modified file 'lib/lp/archivepublisher/customupload.py'
--- lib/lp/archivepublisher/customupload.py	2010-08-20 20:31:18 +0000
+++ lib/lp/archivepublisher/customupload.py	2012-01-06 11:15:30 +0000
@@ -83,7 +83,7 @@
 class CustomUpload:
     """Base class for custom upload handlers"""
 
-    # The following should be overriden by subclasses, probably in
+    # The following should be overridden by subclasses, probably in
     # their __init__
     targetdir = None
     version = None

=== modified file 'lib/lp/archiveuploader/dscfile.py'
--- lib/lp/archiveuploader/dscfile.py	2012-01-05 04:40:45 +0000
+++ lib/lp/archiveuploader/dscfile.py	2012-01-06 11:15:30 +0000
@@ -511,9 +511,9 @@
             else:
                 # try to check dsc-mentioned file against its copy already
                 # in librarian, if it's new (aka not found in librarian)
-                # dismiss. It prevent us to have scary duplicated filenames
-                # in Librarian and missapplied files in archive, fixes
-                # bug # 38636 and friends.
+                # dismiss. It prevents us from having scary duplicated
+                # filenames in Librarian and misapplied files in archive,
+                # fixes bug # 38636 and friends.
                 if sub_dsc_file.digest != library_file.content.md5:
                     yield UploadError(
                         "File %s already exists in %s, but uploaded version "

=== modified file 'lib/lp/archiveuploader/nascentuploadfile.py'
--- lib/lp/archiveuploader/nascentuploadfile.py	2012-01-03 05:05:39 +0000
+++ lib/lp/archiveuploader/nascentuploadfile.py	2012-01-06 11:15:30 +0000
@@ -303,7 +303,7 @@
 
         They need to satisfy at least the NEW queue constraints that includes
         SourcePackageRelease creation, so component and section need to exist.
-        Even if they might be overriden in the future.
+        Even if they might be overridden in the future.
         """
         NascentUploadFile.__init__(
             self, filepath, digest, size, component_and_section,

=== modified file 'lib/lp/bugs/externalbugtracker/bugzilla.py'
--- lib/lp/bugs/externalbugtracker/bugzilla.py	2012-01-01 02:58:52 +0000
+++ lib/lp/bugs/externalbugtracker/bugzilla.py	2012-01-06 11:15:30 +0000
@@ -318,7 +318,7 @@
     def initializeRemoteBugDB(self, bug_ids):
         """See `ExternalBugTracker`.
 
-        This method is overriden so that Bugzilla version issues can be
+        This method is overridden so that Bugzilla version issues can be
         accounted for.
         """
         if self.version is None:

=== modified file 'lib/lp/bugs/externalbugtracker/mantis.py'
--- lib/lp/bugs/externalbugtracker/mantis.py	2012-01-01 02:58:52 +0000
+++ lib/lp/bugs/externalbugtracker/mantis.py	2012-01-06 11:15:30 +0000
@@ -376,7 +376,7 @@
         The Mantis bug view page uses HTML tables for both layout and
         representing tabular data, often within the same table. This
         method assumes that the key and value are on the same row,
-        adjacent to one another, with the key preceeding the value:
+        adjacent to one another, with the key preceding the value:
 
         ...
         <td>Key</td>
@@ -409,7 +409,7 @@
         The Mantis bug view page uses HTML tables for both layout and
         representing tabular data, often within the same table. This
         method assumes that the key and value are within the same
-        column on adjacent rows, with the key preceeding the value:
+        column on adjacent rows, with the key preceding the value:
 
         ...
         <tr>...<td>Key</td>...</tr>

=== modified file 'lib/lp/bugs/model/tests/test_bug.py'
--- lib/lp/bugs/model/tests/test_bug.py	2012-01-04 17:46:45 +0000
+++ lib/lp/bugs/model/tests/test_bug.py	2012-01-06 11:15:30 +0000
@@ -398,7 +398,7 @@
         with person_logged_in(duplicate_bug.owner):
             duplicate_bug.markAsDuplicate(bug)
             # We unsubscribe the owner of the duplicate to avoid muddling
-            # the results retuned by getSubscribersFromDuplicates()
+            # the results returned by getSubscribersFromDuplicates()
             duplicate_bug.unsubscribe(
                 duplicate_bug.owner, duplicate_bug.owner)
         for level in BugNotificationLevel.items:
@@ -422,7 +422,7 @@
         with person_logged_in(duplicate_bug.owner):
             duplicate_bug.markAsDuplicate(bug)
             # We unsubscribe the owner of the duplicate to avoid muddling
-            # the results retuned by getSubscribersFromDuplicates()
+            # the results returned by getSubscribersFromDuplicates()
             duplicate_bug.unsubscribe(
                 duplicate_bug.owner, duplicate_bug.owner)
         subscriber = self.factory.makePerson()

=== modified file 'lib/lp/bugs/model/tests/test_bugsubscriptionfiltertag.py'
--- lib/lp/bugs/model/tests/test_bugsubscriptionfiltertag.py	2012-01-01 02:58:52 +0000
+++ lib/lp/bugs/model/tests/test_bugsubscriptionfiltertag.py	2012-01-06 11:15:30 +0000
@@ -53,7 +53,7 @@
     def test_qualified_tag(self):
         """
         `BugSubscriptionFilterTag.qualified_tag` returns a tag with a
-        preceeding hyphen if `include` is `False`.
+        preceding hyphen if `include` is `False`.
         """
         bug_sub_filter_tag = BugSubscriptionFilterTag()
         bug_sub_filter_tag.tag = u"foo"

=== modified file 'lib/lp/bugs/stories/initial-bug-contacts/xx-initial-bug-contacts.txt'
--- lib/lp/bugs/stories/initial-bug-contacts/xx-initial-bug-contacts.txt	2011-12-24 15:18:32 +0000
+++ lib/lp/bugs/stories/initial-bug-contacts/xx-initial-bug-contacts.txt	2012-01-06 11:15:30 +0000
@@ -11,7 +11,7 @@
   ...
   LinkNotFoundError
 
-Collin is an an Ubuntu owner and can set the bug supervisor role.
+Colin is an Ubuntu owner and can set the bug supervisor role.
 
   >>> colin_browser = setupBrowser(
   ...     auth='Basic colin.watson@xxxxxxxxxxxxxxx:test')
@@ -40,7 +40,7 @@
   ...     ' colin.watson@xxxxxxxxxxxxxxx ')
   >>> colin_browser.getControl("Change").click()
 
-And then collin is redirected to the distribution bugs page.
+And then Colin is redirected to the distribution bugs page.
 
     >>> print extract_text(find_tag_by_id(
     ...     colin_browser.contents, 'bug-supervisor'))

=== modified file 'lib/lp/buildmaster/doc/buildqueue.txt'
--- lib/lp/buildmaster/doc/buildqueue.txt	2011-12-30 06:14:56 +0000
+++ lib/lp/buildmaster/doc/buildqueue.txt	2012-01-06 11:15:30 +0000
@@ -58,7 +58,7 @@
     u'bob'
 
 'logtail' is a text field which stores up to 1 Kbyte of the last
-logged actions during the build process, it is updated according the
+logged actions during the build process, it is updated according to the
 frequency set in buildd-slavescanner, normally 10 seconds, see
 buildd-slavescanner.txt for further information:
 

=== modified file 'lib/lp/buildmaster/model/builder.py'
--- lib/lp/buildmaster/model/builder.py	2012-01-03 12:11:57 +0000
+++ lib/lp/buildmaster/model/builder.py	2012-01-06 11:15:30 +0000
@@ -315,8 +315,8 @@
 def rescueBuilderIfLost(builder, logger=None):
     """See `IBuilder`."""
     # 'ident_position' dict relates the position of the job identifier
-    # token in the sentence received from status(), according the
-    # two status we care about. See lp:launchpad-buildd
+    # token in the sentence received from status(), according to the
+    # two statuses we care about. See lp:launchpad-buildd
     # for further information about sentence format.
     ident_position = {
         'BuilderStatus.BUILDING': 1,

=== modified file 'lib/lp/code/browser/branchlisting.py'
--- lib/lp/code/browser/branchlisting.py	2012-01-05 13:20:27 +0000
+++ lib/lp/code/browser/branchlisting.py	2012-01-06 11:15:30 +0000
@@ -881,7 +881,7 @@
         branches registered by a particular user for the counts that
         appear at the top of a branch listing page.
 
-        This should be overriden in subclasses to restrict to, for
+        This should be overridden in subclasses to restrict to, for
         example, the set of branches of a particular product.
         """
         return getUtility(IAllBranches).visibleByUser(self.user)

=== modified file 'lib/lp/code/interfaces/branchvisibilitypolicy.py'
--- lib/lp/code/interfaces/branchvisibilitypolicy.py	2011-12-24 16:54:44 +0000
+++ lib/lp/code/interfaces/branchvisibilitypolicy.py	2012-01-06 11:15:30 +0000
@@ -53,7 +53,7 @@
         through team membership.
 
         If there are a number of rules that apply for the owner of the branch
-        then the most restrictive rule is retuned.
+        then the most restrictive rule is returned.
         """
 
     def isUsingInheritedBranchVisibilityPolicy():

=== modified file 'lib/lp/code/model/tests/test_branchpuller.py'
--- lib/lp/code/model/tests/test_branchpuller.py	2011-12-30 06:14:56 +0000
+++ lib/lp/code/model/tests/test_branchpuller.py	2012-01-06 11:15:30 +0000
@@ -167,27 +167,27 @@
     """Tests for acquiring branches to pull.
 
     The tests apply to branches accessed directly or through an XML-RPC style
-    endpoint -- implement `assertNoBranchIsAquired`, `assertBranchIsAquired`
+    endpoint -- implement `assertNoBranchIsAcquired`, `assertBranchIsAcquired`
     and `startMirroring` as appropriate.
     """
 
-    def assertNoBranchIsAquired(self, *branch_types):
+    def assertNoBranchIsAcquired(self, *branch_types):
         """Assert that there is no branch to pull.
 
         :param branch_types: A list of branch types to pass to
             acquireBranchToPull.  Passing none means consider all types of
             branch.
         """
-        raise NotImplementedError(self.assertNoBranchIsAquired)
+        raise NotImplementedError(self.assertNoBranchIsAcquired)
 
-    def assertBranchIsAquired(self, branch, *branch_types):
+    def assertBranchIsAcquired(self, branch, *branch_types):
         """Assert that ``branch`` is the next branch to be pulled.
 
         :param branch_types: A list of branch types to pass to
             acquireBranchToPull.  Passing none means consider all types of
             branch.
         """
-        raise NotImplementedError(self.assertBranchIsAquired)
+        raise NotImplementedError(self.assertBranchIsAcquired)
 
     def startMirroring(self, branch):
         """Mark that ``branch`` has begun mirroring."""
@@ -196,14 +196,14 @@
     def test_empty(self):
         # If there is no branch that needs pulling, acquireBranchToPull
         # returns None.
-        self.assertNoBranchIsAquired()
+        self.assertNoBranchIsAcquired()
 
     def test_simple(self):
         # If there is one branch that needs mirroring, acquireBranchToPull
         # returns that.
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)
         branch.requestMirror()
-        self.assertBranchIsAquired(branch)
+        self.assertBranchIsAcquired(branch)
 
     def test_remote_branch_not_acquired(self):
         # On a few occasions a branch type that is mirrored has been
@@ -212,7 +212,7 @@
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)
         branch.requestMirror()
         removeSecurityProxy(branch).branch_type = BranchType.REMOTE
-        self.assertNoBranchIsAquired()
+        self.assertNoBranchIsAcquired()
 
     def test_private(self):
         # If there is a private branch that needs mirroring,
@@ -220,14 +220,14 @@
         branch = self.factory.makeAnyBranch(
             branch_type=BranchType.MIRRORED, private=True)
         removeSecurityProxy(branch).requestMirror()
-        self.assertBranchIsAquired(branch)
+        self.assertBranchIsAcquired(branch)
 
     def test_no_inprogress(self):
         # If a branch is being mirrored, it is not returned.
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)
         branch.requestMirror()
         self.startMirroring(branch)
-        self.assertNoBranchIsAquired()
+        self.assertNoBranchIsAcquired()
 
     def test_first_requested_returned(self):
         # If two branches are to be mirrored, the one that was requested first
@@ -244,28 +244,28 @@
         second_branch.requestMirror()
         naked_second_branch = removeSecurityProxy(second_branch)
         naked_second_branch.next_mirror_time -= timedelta(seconds=50)
-        self.assertBranchIsAquired(naked_first_branch)
+        self.assertBranchIsAcquired(naked_first_branch)
 
     def test_type_filter_mirrrored_returns_mirrored(self):
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)
         branch.requestMirror()
-        self.assertBranchIsAquired(branch, BranchType.MIRRORED)
+        self.assertBranchIsAcquired(branch, BranchType.MIRRORED)
 
     def test_type_filter_imported_does_not_return_mirrored(self):
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)
         branch.requestMirror()
-        self.assertNoBranchIsAquired(BranchType.IMPORTED)
+        self.assertNoBranchIsAcquired(BranchType.IMPORTED)
 
     def test_type_filter_mirrored_imported_returns_mirrored(self):
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)
         branch.requestMirror()
-        self.assertBranchIsAquired(
+        self.assertBranchIsAcquired(
             branch, BranchType.MIRRORED, BranchType.IMPORTED)
 
     def test_type_filter_mirrored_imported_returns_imported(self):
         branch = self.factory.makeAnyBranch(branch_type=BranchType.IMPORTED)
         branch.requestMirror()
-        self.assertBranchIsAquired(
+        self.assertBranchIsAcquired(
             branch, BranchType.MIRRORED, BranchType.IMPORTED)
 
 
@@ -275,13 +275,13 @@
 
     layer = DatabaseFunctionalLayer
 
-    def assertNoBranchIsAquired(self, *branch_types):
+    def assertNoBranchIsAcquired(self, *branch_types):
         """See `AcquireBranchToPullTests`."""
         acquired_branch = getUtility(IBranchPuller).acquireBranchToPull(
             *branch_types)
         self.assertEqual(None, acquired_branch)
 
-    def assertBranchIsAquired(self, branch, *branch_types):
+    def assertBranchIsAcquired(self, branch, *branch_types):
         """See `AcquireBranchToPullTests`."""
         acquired_branch = getUtility(IBranchPuller).acquireBranchToPull(
             *branch_types)

=== modified file 'lib/lp/code/xmlrpc/tests/test_codehosting.py'
--- lib/lp/code/xmlrpc/tests/test_codehosting.py	2011-12-30 06:14:56 +0000
+++ lib/lp/code/xmlrpc/tests/test_codehosting.py	2012-01-06 11:15:30 +0000
@@ -1169,13 +1169,13 @@
         self.codehosting_api = frontend.getCodehostingEndpoint()
         self.factory = frontend.getLaunchpadObjectFactory()
 
-    def assertNoBranchIsAquired(self, *branch_types):
+    def assertNoBranchIsAcquired(self, *branch_types):
         """See `AcquireBranchToPullTests`."""
         branch_types = tuple(branch_type.name for branch_type in branch_types)
         pull_info = self.codehosting_api.acquireBranchToPull(branch_types)
         self.assertEqual((), pull_info)
 
-    def assertBranchIsAquired(self, branch, *branch_types):
+    def assertBranchIsAcquired(self, branch, *branch_types):
         """See `AcquireBranchToPullTests`."""
         branch = removeSecurityProxy(branch)
         branch_types = tuple(branch_type.name for branch_type in branch_types)
@@ -1197,7 +1197,7 @@
         # This is a bit random, but it works.  acquireBranchToPull marks the
         # branch it returns as started mirroring, but we should check that the
         # one we want is returned...
-        self.assertBranchIsAquired(branch, branch.branch_type)
+        self.assertBranchIsAcquired(branch, branch.branch_type)
 
     def test_branch_type_returned_mirrored(self):
         branch = self.factory.makeAnyBranch(branch_type=BranchType.MIRRORED)

=== modified file 'lib/lp/codehosting/codeimport/tests/test_dispatcher.py'
--- lib/lp/codehosting/codeimport/tests/test_dispatcher.py	2012-01-01 02:58:52 +0000
+++ lib/lp/codehosting/codeimport/tests/test_dispatcher.py	2012-01-06 11:15:30 +0000
@@ -60,7 +60,7 @@
         self.assertEqual(socket.gethostname(), dispatcher.getHostname())
 
     def test_getHostnameOverride(self):
-        # getHostname can be overriden by the config for testing, however.
+        # getHostname can be overridden by the config for testing, however.
         dispatcher = self.makeDispatcher()
         self.pushConfig('codeimportdispatcher', forced_hostname='test-value')
         self.assertEqual('test-value', dispatcher.getHostname())

=== modified file 'lib/lp/codehosting/safe_open.py'
--- lib/lp/codehosting/safe_open.py	2011-12-22 09:05:46 +0000
+++ lib/lp/codehosting/safe_open.py	2012-01-06 11:15:30 +0000
@@ -290,7 +290,7 @@
     def followReference(self, url):
         """Get the branch-reference value at the specified url.
 
-        This exists as a separate method only to be overriden in unit tests.
+        This exists as a separate method only to be overridden in unit tests.
         """
         bzrdir = self._open_dir(url)
         return bzrdir.get_branch_reference()

=== modified file 'lib/lp/registry/browser/distroseries.py'
--- lib/lp/registry/browser/distroseries.py	2012-01-05 20:11:40 +0000
+++ lib/lp/registry/browser/distroseries.py	2012-01-06 11:15:30 +0000
@@ -342,7 +342,7 @@
     def createStatusField(self):
         """Create the 'status' field.
 
-        Create the status vocabulary according the current distroseries
+        Create the status vocabulary according to the current distroseries
         status:
          * stable   -> CURRENT, SUPPORTED, OBSOLETE
          * unstable -> EXPERIMENTAL, DEVELOPMENT, FROZEN, FUTURE, CURRENT

=== modified file 'lib/lp/registry/doc/distroseries.txt'
--- lib/lp/registry/doc/distroseries.txt	2011-12-30 06:14:56 +0000
+++ lib/lp/registry/doc/distroseries.txt	2012-01-06 11:15:30 +0000
@@ -167,7 +167,7 @@
 See distroseries-publishing-lookups.txt for more information.
 
 canUploadToPocket method helps us to decide if an upload is allowed or
-not, according the distroseries status and the upload target pocket.
+not, according to the distroseries status and the upload target pocket.
 
     >>> from lp.registry.interfaces.distribution import IDistributionSet
     >>> ubuntu = getUtility(IDistributionSet)['ubuntu']
@@ -332,8 +332,8 @@
 
 Check if the attributes of an DRSPR instance for the just initialized
 distroseries are sane. A DRSPR instance should filter attributes of
-a SPR according the distroseries in question (practically according
-what is published in this distrorelelase)
+a SPR according to the distroseries in question (practically according
+what is published in this distrorelease)
 
 Since the initialize-from-parent procedure copies the latest
 publications from the parent IDRSPR.builds should be empty, reflecting

=== modified file 'lib/lp/registry/doc/teammembership.txt'
--- lib/lp/registry/doc/teammembership.txt	2012-01-03 22:28:10 +0000
+++ lib/lp/registry/doc/teammembership.txt	2012-01-06 11:15:30 +0000
@@ -675,7 +675,7 @@
 
 Now we commit the changes and run the cronscript.
 XXX: flush_database_updates() shouldn't be needed. This seems to be
-Bug 3989 -- StuarBishop 20060713
+Bug 3989 -- StuartBishop 20060713
 
     >>> flush_database_updates()
     >>> transaction.commit()

=== modified file 'lib/lp/registry/interfaces/gpg.py'
--- lib/lp/registry/interfaces/gpg.py	2011-12-24 16:54:44 +0000
+++ lib/lp/registry/interfaces/gpg.py	2012-01-06 11:15:30 +0000
@@ -75,8 +75,8 @@
     20: "G", # ElGamal, compromised
 
     FIXME
-    Rewrite it according the experimental API retuning also a name attribute
-    tested on 'algorithmname' attribute
+    Rewrite it according to the experimental API returning also a name
+    attribute tested on 'algorithmname' attribute
 
     """
 

=== modified file 'lib/lp/registry/interfaces/irc.py'
--- lib/lp/registry/interfaces/irc.py	2011-12-24 16:54:44 +0000
+++ lib/lp/registry/interfaces/irc.py	2012-01-06 11:15:30 +0000
@@ -31,7 +31,7 @@
     """A person's nickname on an IRC network."""
     export_as_webservice_entry('irc_id')
     id = Int(title=_("Database ID"), required=True, readonly=True)
-    # schema=Interface will be overriden in person.py because of circular
+    # schema=Interface will be overridden in person.py because of circular
     # dependencies.
     person = exported(
         Reference(

=== modified file 'lib/lp/registry/interfaces/jabber.py'
--- lib/lp/registry/interfaces/jabber.py	2011-12-24 16:54:44 +0000
+++ lib/lp/registry/interfaces/jabber.py	2012-01-06 11:15:30 +0000
@@ -31,7 +31,7 @@
     """Jabber specific user ID """
     export_as_webservice_entry('jabber_id')
     id = Int(title=_("Database ID"), required=True, readonly=True)
-    # schema=Interface will be overriden in person.py because of circular
+    # schema=Interface will be overridden in person.py because of circular
     # dependencies.
     person = exported(
         Reference(

=== modified file 'lib/lp/registry/interfaces/wikiname.py'
--- lib/lp/registry/interfaces/wikiname.py	2011-12-24 16:54:44 +0000
+++ lib/lp/registry/interfaces/wikiname.py	2012-01-06 11:15:30 +0000
@@ -28,7 +28,7 @@
     """Wiki for Users"""
     export_as_webservice_entry(publish_web_link=False)
     id = Int(title=_("Database ID"), required=True, readonly=True)
-    # schema=Interface will be overriden in person.py because of circular
+    # schema=Interface will be overridden in person.py because of circular
     # dependencies.
     person = exported(
         Reference(

=== modified file 'lib/lp/registry/model/codeofconduct.py'
--- lib/lp/registry/model/codeofconduct.py	2011-12-30 06:14:56 +0000
+++ lib/lp/registry/model/codeofconduct.py	2012-01-06 11:15:30 +0000
@@ -114,7 +114,7 @@
 
     @property
     def _filename(self):
-        """Rebuild filename according the local version."""
+        """Rebuild filename according to the local version."""
         # Recover the path for CoC from a Component
         path = getUtility(ICodeOfConductConf).path
         return os.path.join(path, self.version + '.txt')

=== modified file 'lib/lp/registry/model/person.py'
--- lib/lp/registry/model/person.py	2011-12-30 06:47:17 +0000
+++ lib/lp/registry/model/person.py	2012-01-06 11:15:30 +0000
@@ -1408,7 +1408,7 @@
             # Initialize cache
             self._inTeam_cache = {}
         else:
-            # Retun from cache or fall through.
+            # Return from cache or fall through.
             try:
                 return self._inTeam_cache[team.id]
             except KeyError:

=== modified file 'lib/lp/registry/model/pillaraffiliation.py'
--- lib/lp/registry/model/pillaraffiliation.py	2012-01-01 02:58:52 +0000
+++ lib/lp/registry/model/pillaraffiliation.py	2012-01-06 11:15:30 +0000
@@ -150,7 +150,7 @@
                 result.append([])
                 continue
 
-            # Sort the affiliation list according the the importance of each
+            # Sort the affiliation list according to the importance of each
             # affiliation role.
             badges.sort(
                 key=lambda badge:

=== modified file 'lib/lp/registry/vocabularies.py'
--- lib/lp/registry/vocabularies.py	2011-12-30 06:14:56 +0000
+++ lib/lp/registry/vocabularies.py	2012-01-06 11:15:30 +0000
@@ -1196,7 +1196,7 @@
         productseries = productrelease.productseries
         product = productseries.product
 
-        # NB: We use '/' as the seperator because '-' is valid in
+        # NB: We use '/' as the separator because '-' is valid in
         # a product.name or productseries.name
         token = '%s/%s/%s' % (
                     product.name, productseries.name, productrelease.version)
@@ -1256,7 +1256,7 @@
 
     def toTerm(self, obj):
         """See `IVocabulary`."""
-        # NB: We use '/' as the seperator because '-' is valid in
+        # NB: We use '/' as the separator because '-' is valid in
         # a product.name or productseries.name
         token = '%s/%s' % (obj.product.name, obj.name)
         return SimpleTerm(

=== modified file 'lib/lp/scripts/garbo.py'
--- lib/lp/scripts/garbo.py	2012-01-05 21:38:46 +0000
+++ lib/lp/scripts/garbo.py	2012-01-06 11:15:30 +0000
@@ -1181,7 +1181,7 @@
 
             loop_logger = self.get_loop_logger(loop_name)
 
-            # Aquire a lock for the task. Multiple garbo processes
+            # Acquire a lock for the task. Multiple garbo processes
             # might be running simultaneously.
             loop_lock_path = os.path.join(
                 LOCK_PATH, 'launchpad-garbo-%s.lock' % loop_name)
@@ -1189,7 +1189,7 @@
             loop_lock = GlobalLock(loop_lock_path, logger=None)
             try:
                 loop_lock.acquire()
-                loop_logger.debug("Aquired lock %s.", loop_lock_path)
+                loop_logger.debug("Acquired lock %s.", loop_lock_path)
             except LockAlreadyAcquired:
                 # If the lock cannot be acquired, but we have plenty
                 # of time remaining, just put the task back to the

=== modified file 'lib/lp/services/config/__init__.py'
--- lib/lp/services/config/__init__.py	2011-12-29 05:40:17 +0000
+++ lib/lp/services/config/__init__.py	2012-01-06 11:15:30 +0000
@@ -365,7 +365,7 @@
 
 
 def commalist(value):
-    """ZConfig validator for a comma seperated list"""
+    """ZConfig validator for a comma separated list"""
     return [v.strip() for v in value.split(',')]
 
 
@@ -450,7 +450,7 @@
         """
         for attr, value in kwargs.iteritems():
             assert attr in self._db_config_attrs, (
-                "%s cannot be overriden" % attr)
+                "%s cannot be overridden" % attr)
             if value is None:
                 if hasattr(self.overrides, attr):
                     delattr(self.overrides, attr)

=== modified file 'lib/lp/services/config/schema-lazr.conf'
--- lib/lp/services/config/schema-lazr.conf	2011-12-24 17:49:30 +0000
+++ lib/lp/services/config/schema-lazr.conf	2012-01-06 11:15:30 +0000
@@ -1433,7 +1433,7 @@
 
 
 [memcache]
-# Comma seperated list of (hostname:port,weight) for the memcache client
+# Comma separated list of (hostname:port,weight) for the memcache client
 # to connect to.
 # datatype: string
 servers: (127.0.0.1:11217,1)

=== modified file 'lib/lp/services/database/doc/storm.txt'
--- lib/lp/services/database/doc/storm.txt	2011-12-21 14:58:31 +0000
+++ lib/lp/services/database/doc/storm.txt	2012-01-06 11:15:30 +0000
@@ -1,6 +1,6 @@
 Note: A more readable version of this is in db-policy.txt. Most of this
 doctest will disappear soon when the auth replication set is collapsed
-back into the main replication set as part of login server seperation.
+back into the main replication set as part of login server separation.
 -- StuartBishop 20100222
 
 In addition to what Storm provides, we also have some Launchpad

=== modified file 'lib/lp/services/database/postgresql.py'
--- lib/lp/services/fields/tests/test_tag_fields.py	2012-01-01 02:58:52 +0000
+++ lib/lp/services/fields/tests/test_tag_fields.py	2012-01-06 11:15:30 +0000
@@ -58,7 +58,7 @@
             self.field.validate, u'-fred')
 
     def test_wildcard(self):
-        # Tag rejects a solitary asterisk, or an asterisk preceeded by
+        # Tag rejects a solitary asterisk, or an asterisk preceded by
         # a minus. This is not surprising seeing as asterisks are
         # forbidden anyway, as are leading minuses. However, this form
         # is special because it is reserved to mean "any tag" or "not
@@ -82,7 +82,7 @@
 
     def test_wildcard(self):
         # SearchTag allows a solitary asterisk, or an asterisk
-        # preceeded by a minus. This means "any tag" or "not any
+        # preceded by a minus. This means "any tag" or "not any
         # tag".
         self.assertIs(None, self.field.validate(u'*'))
         self.assertIs(None, self.field.validate(u'-*'))

=== modified file 'lib/lp/services/geoip/helpers.py'
--- lib/lp/services/geoip/helpers.py	2010-10-25 05:33:20 +0000
+++ lib/lp/services/geoip/helpers.py	2012-01-06 11:15:30 +0000
@@ -67,7 +67,7 @@
     if ipaddresses is None:
         return None
 
-    # We actually get a comma seperated list of addresses. We need to throw
+    # We actually get a comma separated list of addresses. We need to throw
     # away the obvious duds, such as loopback addresses
     ipaddresses = [addr.strip() for addr in ipaddresses.split(',')]
     ipaddresses = [

=== modified file 'lib/lp/services/librarianserver/librariangc.py'
--- lib/lp/services/librarianserver/librariangc.py	2011-12-30 06:14:56 +0000
+++ lib/lp/services/librarianserver/librariangc.py	2012-01-06 11:15:30 +0000
@@ -144,7 +144,7 @@
         """)
     rows = list(cur.fetchall())
 
-    # Merge the duplicate entries, each one in a seperate transaction
+    # Merge the duplicate entries, each one in a separate transaction
     for sha1, filesize in rows:
         cur = con.cursor()
 

=== modified file 'lib/lp/services/memcache/tales.py'
--- lib/lp/services/memcache/tales.py	2012-01-01 02:58:52 +0000
+++ lib/lp/services/memcache/tales.py	2012-01-06 11:15:30 +0000
@@ -73,7 +73,7 @@
 
             authenticated: Authenticated user share a copy of the cached
                            information, and unauthenticated users share
-                           a seperate copy. Use this when information is
+                           a separate copy. Use this when information is
                            being hidden from unauthenticated users, eg.
                            for bug comments where email addresses are
                            obfuscated for unauthenticated users.

=== modified file 'lib/lp/services/scripts/base.py'
--- lib/lp/services/scripts/base.py	2011-12-30 06:14:56 +0000
+++ lib/lp/services/scripts/base.py	2012-01-06 11:15:30 +0000
@@ -352,13 +352,13 @@
             profiler.dump_stats(self.options.profile)
 
     def _init_zca(self, use_web_security):
-        """Initialize the ZCA, this can be overriden for testing purpose."""
+        """Initialize the ZCA, this can be overridden for testing purposes."""
         scripts.execute_zcml_for_scripts(use_web_security=use_web_security)
 
     def _init_db(self, isolation):
         """Initialize the database transaction.
 
-        Can be overriden for testing purpose.
+        Can be overridden for testing purposes.
         """
         dbuser = self.dbuser
         if dbuser is None:

=== modified file 'lib/lp/services/webapp/launchbag.py'
--- lib/lp/services/webapp/launchbag.py	2011-12-30 06:14:56 +0000
+++ lib/lp/services/webapp/launchbag.py	2012-01-06 11:15:30 +0000
@@ -172,7 +172,7 @@
     """
     launchbag = getUtility(IOpenLaunchBag)
     # Basic auths principal identified event is also an ILoggedInEvent.
-    # Cookie auth seperates these two events.
+    # Cookie auth separates these two events.
     loggedinevent = ILoggedInEvent(event, None)
     if loggedinevent is None:
         # We must be using session auth.

=== modified file 'lib/lp/services/webapp/vhosts.py'
--- lib/lp/services/webapp/vhosts.py	2011-12-29 05:29:36 +0000
+++ lib/lp/services/webapp/vhosts.py	2012-01-06 11:15:30 +0000
@@ -59,7 +59,7 @@
     the current Launchpad instance.
 
     self.use_https : do we use http or https
-                    (unless overriden for a particular virutal host)
+                    (unless overridden for a particular virtual host)
     self.configs : dict of 'config item name from conf file':VirtualHostConfig.
                    so, like this:
                    {'mainsite': config_for_mainsite,

=== modified file 'lib/lp/soyuz/adapters/overrides.py'
--- lib/lp/soyuz/adapters/overrides.py	2012-01-01 02:58:52 +0000
+++ lib/lp/soyuz/adapters/overrides.py	2012-01-06 11:15:30 +0000
@@ -356,10 +356,10 @@
             self, archive, distroseries, pocket, binaries)
         existing = set(
             (
-                overide.binary_package_name,
-                overide.distro_arch_series.architecturetag,
+                override.binary_package_name,
+                override.distro_arch_series.architecturetag,
             )
-            for overide in overrides)
+            for override in overrides)
         missing = total.difference(existing)
         if missing:
             unknown = UnknownOverridePolicy.calculateBinaryOverrides(

=== modified file 'lib/lp/soyuz/browser/build.py'
--- lib/lp/soyuz/browser/build.py	2012-01-01 02:58:52 +0000
+++ lib/lp/soyuz/browser/build.py	2012-01-06 11:15:30 +0000
@@ -588,7 +588,7 @@
         if self.text is not None or self.arch_tag is not None:
             binary_only = True
 
-        # request context build records according the selected state
+        # request context build records according to the selected state
         builds = self.context.getBuildRecords(
             build_state=self.state, name=self.text, arch_tag=self.arch_tag,
             user=self.user, binary_only=binary_only)

=== modified file 'lib/lp/soyuz/doc/archive-dependencies.txt'
--- lib/lp/soyuz/doc/archive-dependencies.txt	2011-12-30 06:14:56 +0000
+++ lib/lp/soyuz/doc/archive-dependencies.txt	2012-01-06 11:15:30 +0000
@@ -81,7 +81,7 @@
 == 'Ogre' components ==
 
 The ubuntu 'ogre-model' ensures that build dependencies are
-consistently spread according the source target component, i.e. a
+consistently spread according to the source target component, i.e. a
 source published in 'main' component is only allowed to depend on
 binaries also published in 'main', on the other hand a source
 published in 'universe' is allowed to depend on binaries published in

=== modified file 'lib/lp/soyuz/doc/build-files.txt'
--- lib/lp/soyuz/doc/build-files.txt	2010-12-09 10:50:22 +0000
+++ lib/lp/soyuz/doc/build-files.txt	2012-01-06 11:15:30 +0000
@@ -21,7 +21,7 @@
     >>> [build] = test_source.getBuilds()
 
 
-IBuild provide a getFileByName() method, which retuns one of the
+IBuild provide a getFileByName() method, which returns one of the
 following file type in its context.
 
  * Binary changesfile: '.changes';

=== modified file 'lib/lp/soyuz/doc/distroarchseries.txt'
--- lib/lp/soyuz/doc/distroarchseries.txt	2011-12-30 06:14:56 +0000
+++ lib/lp/soyuz/doc/distroarchseries.txt	2012-01-06 11:15:30 +0000
@@ -316,7 +316,7 @@
 DistroArchSeries for which we support PPA building can be obtained via
 another distroseries method called 'virtualized_architectures'.
 
-For testing purpose we can compare the results of a
+For testing purposes we can compare the results of a
 manually-calculated set of warty architectures for which we support
 PPA  and the actual value returned from the 'ppa_architecture'
 property.

=== modified file 'lib/lp/soyuz/doc/distroseriesqueue-ddtp-tarball.txt'
--- lib/lp/soyuz/doc/distroseriesqueue-ddtp-tarball.txt	2011-12-29 05:29:36 +0000
+++ lib/lp/soyuz/doc/distroseriesqueue-ddtp-tarball.txt	2012-01-06 11:15:30 +0000
@@ -41,7 +41,7 @@
 
     >>> breezy_autotest.changeslist = 'test@xxxxxxxxxxx'
 
-First, test the rejection of a missapplied changesfile name, which
+First, test the rejection of a misapplied changesfile name, which
 doesn't follow the accepted format,  "<pkg>_<version>_<arch>.changes"
 
     >>> sync_policy = getPolicy(

=== modified file 'lib/lp/soyuz/doc/distroseriesqueue-dist-upgrader.txt'
--- lib/lp/soyuz/doc/distroseriesqueue-dist-upgrader.txt	2011-12-29 05:29:36 +0000
+++ lib/lp/soyuz/doc/distroseriesqueue-dist-upgrader.txt	2012-01-06 11:15:30 +0000
@@ -18,7 +18,7 @@
 
     >>> login('foo.bar@xxxxxxxxxxxxx')
 
-First, test the rejection of a missapplied changesfile name:
+First, test the rejection of a misapplied changesfile name:
 
     >>> sync_policy = getPolicy(
     ...     name='sync', distro='ubuntutest', distroseries=None)
@@ -75,7 +75,7 @@
 
 We need to commit the transaction to be able to use the librarian files.
 XXX: flush_database_updates() shouldn't be needed. This seems to be
-Bug 3989 -- StuarBishop 20060713
+Bug 3989 -- StuartBishop 20060713
 
     >>> flush_database_updates()
     >>> transaction.commit()
@@ -111,8 +111,8 @@
     ...
 
 
-Accepting from rejected queue (ressurecting an reject upload is also
-very unlikely, however it's only for testing purpose, fix #54649):
+Accepting from rejected queue (resurrecting an reject upload is also
+very unlikely, however it's only for testing purposes, fix #54649):
 
     >>> process = subprocess.Popen([sys.executable, script, "-Q", "rejected",
     ...                             "-s", "breezy-autotest", "accept", "dist",
@@ -280,7 +280,7 @@
 Dist Upgrader to PPA
 --------------------
 
-Custom uploads for PPAs should works as expected, i.e, publish its
+Custom uploads for PPAs should work as expected, i.e, publish its
 files in the respective PPA location.
 
     >>> from lp.registry.interfaces.person import IPersonSet

=== modified file 'lib/lp/soyuz/doc/distroseriesqueue.txt'
--- lib/lp/soyuz/doc/distroseriesqueue.txt	2011-12-28 17:03:06 +0000
+++ lib/lp/soyuz/doc/distroseriesqueue.txt	2012-01-06 11:15:30 +0000
@@ -87,7 +87,7 @@
     >>> new_queue = hoary.getPackageUploads(PackageUploadStatus.NEW)
 
 Use state-machine method provided by PackageUpload to ACCEPT an
-upload. If some designed check according the request state do not
+upload. If some designed check according to the request state do not
 pass, the state-machine methods will raise an exception indicating the
 upload can not have that state.
 

=== modified file 'lib/lp/soyuz/doc/fakepackager.txt'
--- lib/lp/soyuz/doc/fakepackager.txt	2011-12-24 15:28:06 +0000
+++ lib/lp/soyuz/doc/fakepackager.txt	2012-01-06 11:15:30 +0000
@@ -20,7 +20,7 @@
     >>> os.path.exists(packager.sandbox_path)
     True
 
-Source 'name' and 'version' and 'gpg_key_id' are set according the
+Source 'name' and 'version' and 'gpg_key_id' are set according to the
 give arguments passed in the initialization.
 
     >>> print packager.name

=== modified file 'lib/lp/soyuz/doc/manage-chroot.txt'
--- lib/lp/soyuz/doc/manage-chroot.txt	2011-12-29 05:29:36 +0000
+++ lib/lp/soyuz/doc/manage-chroot.txt	2012-01-06 11:15:30 +0000
@@ -68,7 +68,7 @@
     >>> process.returncode
     0
     >>> print stderr
-    INFO    Creating lockfile: /var/lock/launchpad-mangage-chroot.lock
+    INFO    Creating lockfile: /var/lock/launchpad-manage-chroot.lock
     DEBUG   Initializing ChrootManager for 'The Hoary Hedgehog Release for i386 (x86)'
     DEBUG   LibraryFileAlias: ..., 25 bytes, 04a60337a417012f7c51fb56d59d2d0d
     DEBUG   PocketChroot for 'The Hoary Hedgehog Release for i386 (x86)' (1) added.

=== modified file 'lib/lp/soyuz/doc/package-relationship-pages.txt'
--- lib/lp/soyuz/doc/package-relationship-pages.txt	2011-12-22 05:09:10 +0000
+++ lib/lp/soyuz/doc/package-relationship-pages.txt	2012-01-06 11:15:30 +0000
@@ -26,7 +26,7 @@
   ...    url=None)
 
 Note that iterations over PackageRelationshipSet are sorted
-alphabetically according the relationship 'name':
+alphabetically according to the relationship 'name':
 
   >>> [relationship.name for relationship in relationship_set]
   ['foobar', 'test']

=== modified file 'lib/lp/soyuz/model/archive.py'
--- lib/lp/soyuz/model/archive.py	2012-01-05 08:51:58 +0000
+++ lib/lp/soyuz/model/archive.py	2012-01-06 11:15:30 +0000
@@ -717,7 +717,7 @@
         """Base clauses and clauseTables for binary publishing queries.
 
         Returns a list of 'clauses' (to be joined in the callsite) and
-        a list of clauseTables required according the given arguments.
+        a list of clauseTables required according to the given arguments.
         """
         clauses = ["""
             BinaryPackagePublishingHistory.archive = %s AND

=== modified file 'lib/lp/soyuz/model/binarypackagebuild.py'
--- lib/lp/soyuz/model/binarypackagebuild.py	2012-01-03 05:05:39 +0000
+++ lib/lp/soyuz/model/binarypackagebuild.py	2012-01-06 11:15:30 +0000
@@ -443,7 +443,7 @@
     def _checkDependencyVersion(self, available, required, relation):
         """Return True if the available version satisfies the context."""
         # This dict maps the package version relationship syntax in lambda
-        # functions which returns boolean according the results of
+        # functions which returns boolean according to the results of
         # apt_pkg.version_compare function (see the order above).
         # For further information about pkg relationship syntax see:
         #
@@ -688,7 +688,7 @@
                 recipients = recipients.union(
                     get_contact_email_addresses(dsc_key.owner))
 
-        # Modify notification contents according the targeted archive.
+        # Modify notification contents according to the targeted archive.
         # 'Archive Tag', 'Subject' and 'Source URL' are customized for PPA.
         # We only send build-notifications to 'buildd-admin' celebrity for
         # main archive candidates.

=== modified file 'lib/lp/soyuz/scripts/ftpmaster.py'
--- lib/lp/soyuz/scripts/ftpmaster.py	2011-12-30 06:14:56 +0000
+++ lib/lp/soyuz/scripts/ftpmaster.py	2012-01-06 11:15:30 +0000
@@ -827,7 +827,7 @@
         removed_by = getUtility(IPersonSet).getByName(self.options.user)
         if removed_by is None:
             raise SoyuzScriptError(
-                "Invalid launchpad usename: %s" % self.options.user)
+                "Invalid launchpad username: %s" % self.options.user)
 
         removables = []
         for packagename in self.args:

=== modified file 'lib/lp/soyuz/scripts/packagecopier.py'
--- lib/lp/soyuz/scripts/packagecopier.py	2012-01-03 05:05:39 +0000
+++ lib/lp/soyuz/scripts/packagecopier.py	2012-01-06 11:15:30 +0000
@@ -93,7 +93,7 @@
 # XXX cprov 2009-06-12: this function should be incorporated in
 # IPublishing.
 def update_files_privacy(pub_record):
-    """Update file privacy according the publishing destination
+    """Update file privacy according to the publishing destination
 
     :param pub_record: One of a SourcePackagePublishingHistory or
         BinaryPackagePublishingHistory record.
@@ -1080,7 +1080,7 @@
         # Invoke the package copy operation.
         copies = PackageCopier.mainTask(self)
 
-        # Fix copies by overriding them according the current ancestry
+        # Fix copies by overriding them according to the current ancestry
         # and re-upload files with privacy mismatch.
         for pub_record in copies:
             pub_record.overrideFromAncestry()

=== modified file 'lib/lp/soyuz/scripts/processdeathrow.py'
--- lib/lp/soyuz/scripts/processdeathrow.py	2010-08-20 20:31:18 +0000
+++ lib/lp/soyuz/scripts/processdeathrow.py	2012-01-06 11:15:30 +0000
@@ -59,10 +59,9 @@
     def processDeathRow(self, archive):
         """Process death-row for the given archive.
 
-        It handles the current DB transaction according with the results
-        of the operatin just executed, i.e, commits successfull runs and
-        aborts runs with errors. It also respects 'dry-run' command-line
-        option.
+        It handles the current DB transaction according to the results of
+        the operation just executed, i.e, commits successful runs and aborts
+        runs with errors. It also respects 'dry-run' command-line option.
         """
         death_row = getDeathRow(
             archive, self.logger, self.options.pool_root)

=== modified file 'lib/lp/soyuz/scripts/soyuz_process_upload.py'
--- lib/lp/soyuz/scripts/soyuz_process_upload.py	2011-06-09 10:50:25 +0000
+++ lib/lp/soyuz/scripts/soyuz_process_upload.py	2012-01-06 11:15:30 +0000
@@ -94,7 +94,7 @@
 
     @property
     def lockfilename(self):
-        """Return specific lockfilename according the policy used.
+        """Return specific lockfilename according to the policy used.
 
         Each different p-u policy requires and uses a different lockfile.
         This is because they are run by different users and are independent

=== modified file 'lib/lp/soyuz/stories/soyuz/xx-builds-pages.txt'
--- lib/lp/soyuz/stories/soyuz/xx-builds-pages.txt	2011-09-27 08:04:53 +0000
+++ lib/lp/soyuz/stories/soyuz/xx-builds-pages.txt	2012-01-06 11:15:30 +0000
@@ -4,7 +4,7 @@
 These pages are based in the BuildRecordView class and
 template/builds-list.pt. Basically they have a buildstate selector
 action via HTTP GET and present a batched list of build records
-according the selected buildstate, by default All.
+according to the selected buildstate, by default All.
 
     >>> def check_builds_options(contents):
     ...     """Check if the label and/or the field for the optional

=== modified file 'lib/lp/soyuz/stories/soyuz/xx-queue-pages.txt'
--- lib/lp/soyuz/stories/soyuz/xx-queue-pages.txt	2011-12-30 06:14:56 +0000
+++ lib/lp/soyuz/stories/soyuz/xx-queue-pages.txt	2012-01-06 11:15:30 +0000
@@ -453,7 +453,7 @@
 only at their file level.  Currently, this UI only permits overriding
 all of the binary files in an upload at once, or not at all.
 
-Thus, the items that are checked for acceptance will also be overriden
+Thus, the items that are checked for acceptance will also be overridden
 depending on the selected values.  This allows many items to be
 all overridden at once with the same value(s).
 

=== modified file 'lib/lp/soyuz/stories/webservice/xx-archive.txt'
--- lib/lp/soyuz/stories/webservice/xx-archive.txt	2011-12-24 17:49:30 +0000
+++ lib/lp/soyuz/stories/webservice/xx-archive.txt	2012-01-06 11:15:30 +0000
@@ -711,7 +711,7 @@
 `PackageCopier` infrastructure, see more information in
 scripts/packagecopier.py.
 
-For testing purpose we will create some publications.
+For testing purposes we will create some publications.
 
     >>> login('foo.bar@xxxxxxxxxxxxx')
     >>> from lp.soyuz.tests.test_publishing import SoyuzTestPublisher

=== modified file 'lib/lp/soyuz/tests/soyuz.py'
--- lib/lp/soyuz/tests/soyuz.py	2012-01-01 02:58:52 +0000
+++ lib/lp/soyuz/tests/soyuz.py	2012-01-06 11:15:30 +0000
@@ -86,7 +86,7 @@
                                         distroseries):
         """Return a list of `SourcePackagePublishingHistory`.
 
-        The publishing records are created according the given
+        The publishing records are created according to the given
         `SourcePackageRelease` and `DistroSeries` for all
         (status, archive, pocket) returned from `sample_publishing_data`.
         """
@@ -110,7 +110,7 @@
                                             distroarchseries):
         """Return a list of `BinaryPackagePublishingHistory`.
 
-        The publishing records are created according the given
+        The publishing records are created according to the given
         `BinaryPackageRelease` and `DistroArchSeries` for all
         (status, archive, pocket) returned from `sample_publishing_data`.
         """

=== modified file 'lib/lp/translations/utilities/doc/gettext_po_exporter.txt'
--- lib/lp/translations/utilities/doc/gettext_po_exporter.txt	2009-07-02 17:16:50 +0000
+++ lib/lp/translations/utilities/doc/gettext_po_exporter.txt	2012-01-06 11:15:30 +0000
@@ -33,7 +33,7 @@
     >>> comments_text_representation(translation_message)
     u'#, fuzzy, c-format'
 
-Simple comments are preceeded by a single # sign.
+Simple comments are preceded by a single # sign.
 
     >>> translation_message = TranslationMessageData()
     >>> translation_message.msgid_singular = u'a'

=== modified file 'scripts/ftpmaster-tools/initialize-from-parent.py'
--- scripts/ftpmaster-tools/initialize-from-parent.py	2012-01-01 03:13:08 +0000
+++ scripts/ftpmaster-tools/initialize-from-parent.py	2012-01-06 11:15:30 +0000
@@ -37,7 +37,7 @@
             metavar="DISTRO", default="ubuntu", help="Distribution name")
         self.parser.add_option(
             "-a", "--arches", dest="arches",
-            help="A comma-seperated list of arches to limit the child "
+            help="A comma-separated list of arches to limit the child "
             "distroseries to inheriting")
 
     def main(self):

=== modified file 'scripts/ftpmaster-tools/lp-query-distro.py'
--- scripts/ftpmaster-tools/lp-query-distro.py	2010-04-27 19:48:39 +0000
+++ scripts/ftpmaster-tools/lp-query-distro.py	2012-01-06 11:15:30 +0000
@@ -12,11 +12,11 @@
    * CURRENT distroseries name: `./ubuntu-helper.py -d ubuntu current`
    * DEVELOPMENT distroseries name:
        `./ubuntu-helper.py -d ubuntu development`
-   * Distorelease architectures:
+   * Distroseries architectures:
        `./lp-query-distro.py -d ubuntu -s feisty archs`
-   * Distorelease official architectures:
+   * Distroseries official architectures:
        `./lp-query-distro.py -d ubuntu -s feisty official_archs`
-   * Distorelease nominated-arch-indep:
+   * Distroseries nominated-arch-indep:
        `./lp-query-distro.py -d ubuntu -s feisty nominated_arch_indep`
 
    Standard Output will carry the successfully executed information and

=== modified file 'scripts/ftpmaster-tools/manage-chroot.py'
--- scripts/ftpmaster-tools/manage-chroot.py	2010-04-27 19:48:39 +0000
+++ scripts/ftpmaster-tools/manage-chroot.py	2012-01-06 11:15:30 +0000
@@ -14,6 +14,6 @@
 
 
 if __name__ == '__main__':
-    script = ManageChrootScript('mangage-chroot', dbuser="fiera")
+    script = ManageChrootScript('manage-chroot', dbuser="fiera")
     script.lock_and_run()
 

=== modified file 'scripts/ftpmaster-tools/sync-source.py'
--- scripts/ftpmaster-tools/sync-source.py	2012-01-03 05:05:39 +0000
+++ scripts/ftpmaster-tools/sync-source.py	2012-01-06 11:15:30 +0000
@@ -163,7 +163,7 @@
             fixed += [" ."]
             fixed_idx += 1
         elif line.startswith(" --"):
-            # Strip any 'blank' lines preceeding the footer
+            # Strip any 'blank' lines preceding the footer
             while fixed[fixed_idx] == " .":
                 fixed.pop()
                 fixed_idx -= 1

=== modified file 'utilities/tcpwatch/tcpwatch.py'
--- utilities/tcpwatch/tcpwatch.py	2012-01-01 03:10:25 +0000
+++ utilities/tcpwatch/tcpwatch.py	2012-01-06 11:15:30 +0000
@@ -877,7 +877,7 @@
                 header_plus = s[:index]
                 consumed = len(data) - (len(s) - index)
                 self.in_header = 0
-                # Remove preceeding blank lines.
+                # Remove preceding blank lines.
                 header_plus = header_plus.lstrip()
                 if not header_plus:
                     self.empty = 1


Follow ups
--- lib/lp/services/database/postgresql.py	2011-12-30 06:14:56 +0000
+++ lib/lp/services/database/postgresql.py	2012-01-06 11:15:30 +0000
@@ -169,7 +169,7 @@
         '''
     cur.execute(sql, dict(table=table))
     for indkey, in cur.fetchall():
         # We have a space seperated list of integer keys into the attribute
         # mapping. Ignore the 0's, as they indicate a function and we don't
         # handle them.
         keys = [
@@ -490,7 +490,7 @@
     """A libpq connection string.
 
     Some PostgreSQL tools take libpq connection strings. Other tools
-    need the components seperated out (such as pg_dump command line
+    need the components separated out (such as pg_dump command line
     arguments). This class allows you to switch easily between formats.
 
     Quoted or escaped values are not supported.
@@ -169,7 +169,7 @@
     cur.execute(sql, dict(table=table))
     for indkey, in cur.fetchall():
-        # We have a space seperated list of integer keys into the attribute
+        # We have a space separated list of integer keys into the attribute
         # mapping. Ignore the 0's, as they indicate a function and we don't
         # handle them.

=== modified file 'lib/lp/services/fields/tests/test_tag_fields.py'